@@ -22,7 +22,7 @@ use Carp;
 use Excel::Writer::XLSX::Chart;
 
 our @ISA     = qw(Excel::Writer::XLSX::Chart);
-our $VERSION = '0.62';
+our $VERSION = '0.63';
 
 
 ###############################################################################
@@ -86,6 +86,15 @@ sub _write_line_chart {
     # Write the series elements.
     $self->_write_series( $_ ) for @series;
 
+    # Write the c:dropLines element.
+    $self->_write_drop_lines();
+
+    # Write the c:hiLowLines element.
+    $self->_write_hi_low_lines();
+
+    # Write the c:upDownBars element.
+    $self->_write_up_down_bars();
+
     # Write the c:marker element.
     $self->_write_marker_value();
 
